package com.ims.eval.controller;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.ims.eval.config.CustomException;
import com.ims.eval.entity.EvaluationDeptRating;
import com.ims.eval.entity.dto.result.R;
import com.ims.eval.service.IEvaluationDeptRatingService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.Arrays;
import java.util.List;

/**
 * 本部部门绩效考核评级
 *
 * @author hlf
 * @date 2023/4/28 16:22
 * 文件说明：
 */
@RestController
@RequestMapping("//evaluation-dept-rating")
public class DepartmentPerformanceAppraisalRatingController {

	@Autowired
	private IEvaluationDeptRatingService evaluationDeptRatingService;

	/**
	 * 部门绩效考核评级列表信息（分页）
	 *
	 * @param pageNum            当前记录起始索引
	 * @param pageSize           每页显示记录数
	 * @param deptName           部门名称
	 * @param annual             月度
	 * @return 结果
	 */
	@GetMapping(value = "list")
	public R list(
		@RequestParam(value = "pageNum") Integer pageNum,
		@RequestParam(value = "pageSize") Integer pageSize,
		@RequestParam(value = "deptName", required = false) String deptName,
		@RequestParam(value = "annual", required = false) String annual) {
		IPage<EvaluationDeptRating> list = evaluationDeptRatingService.listPage(pageNum, pageSize, deptName, annual);
		return R.ok().data(list);
	}

	/**
	 * 部门绩效考核评级信息
	 *
	 * @return 结果
	 */
	@GetMapping(value = "listAll")
	public R listAll() {
		List<EvaluationDeptRating> list = evaluationDeptRatingService.list();
		return R.ok().data(list);
	}

	/**
	 * 新增/修改部门绩效考核评级信息
	 *
	 * @param evaluationDeptRating 部门绩效考核评级实体
	 * @return 结果
	 */
	@PostMapping(value = "/save")
	public R addAll(@RequestBody EvaluationDeptRating evaluationDeptRating) {
		try {
			boolean b = evaluationDeptRatingService.saveOrUpdate(evaluationDeptRating);
			if (b) {
				return R.ok().data(b);
			} else {
				return R.error().data("保存失败！");
			}
		} catch (CustomException e) {
			return R.customError(e.getMessage()).data("失败！");
		}
	}

	/**
	 * 批量删除部门绩效考核评级信息
	 *
	 * @param ids
	 * @return
	 */
	@PostMapping(value = "/removeAll/{ids}")
	public R deleteAll(@PathVariable("ids") String ids) {
		String[] strings = ids.split(",");
		boolean b = evaluationDeptRatingService.removeByIds(Arrays.asList(strings));
		if (b) {
			return R.ok().data(b);
		} else {
			return R.error().data("删除失败！");
		}
	}
}
