package com.ims.eval.controller;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.ims.eval.config.CustomException;
import com.ims.eval.entity.*;
import com.ims.eval.entity.dto.result.R;
import com.ims.eval.service.*;
import com.ims.eval.util.ExcelUtil;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.http.HttpServletRequest;
import java.io.InputStream;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;

/**
 * 本部部门业绩指标计划
 *
 * @author hlf
 * @date 2023/4/26 14:15
 * 文件说明：
 */
@Slf4j
@RestController
@RequestMapping("//evaluation-dept-plan")
public class DepartmentalPerformanceIndicatorPlanController {

	@Autowired
	private IEvaluationDeptBusinessPlanService evaluationDeptBusinessPlanService;

	@Autowired
	private IEvaluationDeptBusinessContentService evaluationDeptBusinessContentService;

	@Autowired
	private HttpServletRequest request;

	/**
	 * 部门考评业务列表信息（分页）
	 *
	 * @param pageNum            当前记录起始索引
	 * @param pageSize           每页显示记录数
	 * @param responsibilityCode 业务编码
	 * @param des                业务简述
	 * @param appraisalYear      月度
	 * @param stage              流程状态
	 * @return 结果
	 */
	@GetMapping(value = "list")
	public R list(
		@RequestParam(value = "pageNum") Integer pageNum,
		@RequestParam(value = "pageSize") Integer pageSize,
		@RequestParam(value = "responsibilityCode", required = false) String responsibilityCode,
		@RequestParam(value = "des", required = false) String des,
		@RequestParam(value = "appraisalYear", required = false) String appraisalYear,
		@RequestParam(value = "stage", required = false) String stage) {
		IPage<EvaluationDeptBusinessPlan> list = evaluationDeptBusinessPlanService.listPage(pageNum, pageSize, responsibilityCode, des, appraisalYear, stage);
		return R.ok().data(list);
	}

	/**
	 * 部门考评业务信息
	 *
	 * @return 结果
	 */
	@GetMapping(value = "listAll")
	public R listAll() {
		List<EvaluationDeptBusinessPlan> list = evaluationDeptBusinessPlanService.list();
		return R.ok().data(list);
	}

	/**
	 * 新增部门考评业务信息
	 *
	 * @param evaluationDeptBusinessPlan 部门考评业务实体
	 * @return 结果
	 */
	@PostMapping(value = "/save")
	public R addAll(@RequestBody EvaluationDeptBusinessPlan evaluationDeptBusinessPlan) {
		try {
			boolean b = evaluationDeptBusinessPlanService.save(evaluationDeptBusinessPlan);
			if (b) {
				return R.ok().data(b);
			} else {
				return R.error().data("保存失败！");
			}
		} catch (CustomException e) {
			return R.customError(e.getMessage()).data("失败！");
		}
	}

	/**
	 * 批量删除部门考评业务信息
	 *
	 * @param ids
	 * @return
	 */
	@PostMapping(value = "/removeAll/{ids}")
	public R deleteAll(@PathVariable("ids") String ids) {
		String[] strings = ids.split(",");
		boolean b = evaluationDeptBusinessPlanService.removeByIds(Arrays.asList(strings));
		if (b) {
			return R.ok().data(b);
		} else {
			return R.error().data("删除失败！");
		}
	}

	/**
	 * 详情
	 *
	 * @param id 业务主键
	 * @return 结果
	 */
	@GetMapping(value = "/details/{id}")
	public R details(@PathVariable("id") String id) {
		List<EvaluationDeptBusinessContent> list = evaluationDeptBusinessContentService.detailsList(id, request);
		return R.ok().data(list);
	}

	/**
	 * 详情-修改
	 *
	 * @param evaluationDeptBusinessContentList 修改内容
	 * @return 结果
	 */
	@PostMapping(value = "/update")
	public R update(@RequestBody List<EvaluationDeptBusinessContent> evaluationDeptBusinessContentList) {
		try {
			boolean b = evaluationDeptBusinessContentService.saveOrUpdateBatch(evaluationDeptBusinessContentList);
			if (b) {
				return R.ok().data(b);
			} else {
				return R.error().data("修改失败！");
			}
		} catch (CustomException e) {
			return R.customError(e.getMessage()).data("失败！");
		}
	}

	/**
	 * 导入
	 *
	 * @param file
	 * @param request
	 * @return
	 */
	@PostMapping(value = "/import")
	public R importData(@RequestParam("file") MultipartFile file, HttpServletRequest request) {
		if (!file.isEmpty()) {
			try {
				//获取原始的文件名
				String originalFilename = file.getOriginalFilename();
				//获取文件类型
				String fileType = originalFilename.substring(originalFilename.lastIndexOf(".") + 1, originalFilename.length());
				//默认从第一行开始读取
				int startRows = 1;
				//获取输入流
				InputStream is = file.getInputStream();
				List<EvaluationDeptBusinessContent> evaluationDeptBusinessContentList = new ArrayList<>();
				//Excel导入导出的单元类
				List<String[]> strings = ExcelUtil.readData(fileType, startRows, true, is);
				//遍历Excel表每一行的数据
				for (String[] str : strings) {
					EvaluationDeptBusinessContent evaluationDeptBusinessContent = new EvaluationDeptBusinessContent();
					evaluationDeptBusinessContent.setId(str[0]);
					evaluationDeptBusinessContent.setBusinessPlanId(str[1]);
					evaluationDeptBusinessContent.setDeptId(str[2]);
					evaluationDeptBusinessContent.setDeptName(str[3]);
					evaluationDeptBusinessContent.setDeptCode(str[4]);
					evaluationDeptBusinessContent.setSerialNumber(str[5]);
					evaluationDeptBusinessContent.setTargetName(str[6]);
					evaluationDeptBusinessContent.setTargetValue(str[7]);
					evaluationDeptBusinessContent.setBaseScore(str[8]);
					evaluationDeptBusinessContent.setEvaluationCriteria(str[9]);
					evaluationDeptBusinessContent.setAuditStatus("-1");
					evaluationDeptBusinessContentList.add(evaluationDeptBusinessContent);
				}
				boolean b = evaluationDeptBusinessContentService.saveOrUpdateBatch(evaluationDeptBusinessContentList);
				if (b) {
					return R.ok().data(b);
				} else {
					return R.error().data("保存失败！");
				}
			} catch (Exception e) {
				log.error("错误", e);
				return R.customError(e.getMessage()).data("失败！");
			}
		}
		return R.customError("上传文件为空！");
	}
}
